@@ -21,6 +21,8 @@
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
+ *
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  */
 
 #include "config.h"
@@ -39,9 +41,6 @@
  * registration of extensions. It will be used by C extensions implementors to
  * register extension implementations from within the peas_register_types module
  * function.
- *
- * Since libpeas 1.22, @extension_type can be an Abstract [alias@GObject.Type]
- * and not just an Interface [alias@GObject.Type].
  **/
 
 typedef void (*PeasObjectModuleRegisterFunc) (PeasObjectModule *module);
@@ -65,36 +64,31 @@ typedef struct {
   GDestroyNotify destroy_func;
 } ExtensionImplementation;
 
-struct _PeasObjectModulePrivate {
+typedef struct _PeasObjectModulePrivate {
   GModule *library;
 
   PeasObjectModuleRegisterFunc register_func;
   GArray *implementations;
 
-  gchar *path;
-  gchar *module_name;
-  gchar *symbol;
+  char *path;
+  char *module_name;
+  char *symbol;
 
   guint resident : 1;
   guint local_linkage : 1;
-};
+} PeasObjectModulePrivate;
 
-G_DEFINE_TYPE_WITH_PRIVATE (PeasObjectModule,
-                            peas_object_module,
-                            G_TYPE_TYPE_MODULE)
-
-#define GET_PRIV(o) \
-  (peas_object_module_get_instance_private (o))
+G_DEFINE_TYPE_WITH_PRIVATE (PeasObjectModule, peas_object_module, G_TYPE_TYPE_MODULE)
 
 #define TYPE_MISSING_PLUGIN_INFO_PROPERTY (G_TYPE_FLAG_RESERVED_ID_BIT)
 
-static const gchar *intern_plugin_info = NULL;
+static const char *intern_plugin_info = NULL;
 
 static gboolean
 peas_object_module_load (GTypeModule *gmodule)
 {
   PeasObjectModule *module = PEAS_OBJECT_MODULE (gmodule);
-  PeasObjectModulePrivate *priv = GET_PRIV (module);
+  PeasObjectModulePrivate *priv = peas_object_module_get_instance_private (module);
 
   g_return_val_if_fail (priv->module_name != NULL, FALSE);
 
@@ -107,11 +101,10 @@ peas_object_module_load (GTypeModule *gmodule)
     }
   else
     {
-      gchar *path;
+      char *path;
       GModuleFlags flags = 0;
-      gchar *fallback_path = NULL;
+      char *fallback_path = NULL;
 
-G_GNUC_BEGIN_IGNORE_DEPRECATIONS
 #ifdef G_OS_WIN32
       if (!g_str_has_suffix (priv->module_name, "." G_MODULE_SUFFIX))
         {
@@ -122,7 +115,7 @@ G_GNUC_BEGIN_IGNORE_DEPRECATIONS
            * not found, as it is commonly the case on Meson builds and
            * also likely in other cases.
            */
-          gchar *mod_file = g_strconcat (priv->module_name, "." G_MODULE_SUFFIX, NULL);
+          char *mod_file = g_strconcat (priv->module_name, "." G_MODULE_SUFFIX, NULL);
           fallback_path = g_module_build_path (priv->path, mod_file);
           g_free (mod_file);
         }
@@ -135,7 +128,6 @@ G_GNUC_BEGIN_IGNORE_DEPRECATIONS
        * is only the .la file in the build directory.
        */
       path = g_module_build_path (priv->path, priv->module_name);
-G_GNUC_END_IGNORE_DEPRECATIONS
 
       if (G_MODULE_SUFFIX[0] != '\0' && g_str_has_suffix (path, "." G_MODULE_SUFFIX))
         path[strlen (path) - strlen (G_MODULE_SUFFIX) - 1] = '\0';
@@ -201,7 +193,7 @@ static void
 peas_object_module_unload (GTypeModule *gmodule)
 {
   PeasObjectModule *module = PEAS_OBJECT_MODULE (gmodule);
-  PeasObjectModulePrivate *priv = GET_PRIV (module);
+  PeasObjectModulePrivate *priv = peas_object_module_get_instance_private (module);
   ExtensionImplementation *impls;
   guint i;
 
@@ -224,7 +216,7 @@ peas_object_module_unload (GTypeModule *gmodule)
 static void
 peas_object_module_init (PeasObjectModule *module)
 {
-  PeasObjectModulePrivate *priv = GET_PRIV (module);
+  PeasObjectModulePrivate *priv = peas_object_module_get_instance_private (module);
 
   priv->implementations = g_array_new (FALSE, FALSE,
                                        sizeof (ExtensionImplementation));
@@ -234,7 +226,7 @@ static void
 peas_object_module_finalize (GObject *object)
 {
   PeasObjectModule *module = PEAS_OBJECT_MODULE (object);
-  PeasObjectModulePrivate *priv = GET_PRIV (module);
+  PeasObjectModulePrivate *priv = peas_object_module_get_instance_private (module);
 
   g_free (priv->path);
   g_free (priv->module_name);
@@ -251,7 +243,7 @@ peas_object_module_get_property (GObject    *object,
                                  GParamSpec *pspec)
 {
   PeasObjectModule *module = PEAS_OBJECT_MODULE (object);
-  PeasObjectModulePrivate *priv = GET_PRIV (module);
+  PeasObjectModulePrivate *priv = peas_object_module_get_instance_private (module);
 
   switch (prop_id)
     {
@@ -283,7 +275,7 @@ peas_object_module_set_property (GObject      *object,
                                  GParamSpec   *pspec)
 {
   PeasObjectModule *module = PEAS_OBJECT_MODULE (object);
-  PeasObjectModulePrivate *priv = GET_PRIV (module);
+  PeasObjectModulePrivate *priv = peas_object_module_get_instance_private (module);
 
   switch (prop_id)
     {
@@ -365,8 +357,6 @@ peas_object_module_class_init (PeasObjectModuleClass *klass)
    * PeasObjectModule:local-linkage
    *
    * Whether the module is loaded with local linkage, i.e. #G_MODULE_BIND_LOCAL.
-   *
-   * Since 1.14
    */
   properties[PROP_LOCAL_LINKAGE] =
     g_param_spec_boolean ("local-linkage",
@@ -391,9 +381,9 @@ peas_object_module_class_init (PeasObjectModuleClass *klass)
  * Returns: a new #PeasObjectModule.
  */
 PeasObjectModule *
-peas_object_module_new (const gchar *module_name,
-                        const gchar *path,
-                        gboolean     resident)
+peas_object_module_new (const char *module_name,
+                        const char *path,
+                        gboolean    resident)
 {
   g_return_val_if_fail (module_name != NULL && *module_name != '\0', NULL);
   g_return_val_if_fail (path != NULL && *path != '\0', NULL);
@@ -415,14 +405,12 @@ peas_object_module_new (const gchar *module_name,
  * Creates a new #PeasObjectModule.
  *
  * Returns: a new #PeasObjectModule.
- *
- * Since 1.14
  */
 PeasObjectModule *
-peas_object_module_new_full (const gchar *module_name,
-                             const gchar *path,
-                             gboolean     resident,
-                             gboolean     local_linkage)
+peas_object_module_new_full (const char *module_name,
+                             const char *path,
+                             gboolean    resident,
+                             gboolean    local_linkage)
 {
   g_return_val_if_fail (module_name != NULL && *module_name != '\0', NULL);
   g_return_val_if_fail (path != NULL && *path != '\0', NULL);
@@ -446,8 +434,8 @@ peas_object_module_new_full (const gchar *module_name,
  * Since: 1.18
  */
 PeasObjectModule *
-peas_object_module_new_embedded (const gchar *module_name,
-                                 const gchar *symbol)
+peas_object_module_new_embedded (const char *module_name,
+                                 const char *symbol)
 {
   g_return_val_if_fail (module_name != NULL && *module_name != '\0', NULL);
   g_return_val_if_fail (symbol != NULL && *symbol != '\0', NULL);
@@ -474,9 +462,6 @@ G_GNUC_BEGIN_IGNORE_DEPRECATIONS
  * If @module does not provide a #PeasFactoryFunc for @exten_type then %NULL is
  * returned.
  *
- * Since libpeas 1.22, @exten_type can be an Abstract [alias@GObject.Type]
- * and not just an Interface [alias@GObject.Type].
- *
  * Returns: (transfer full) (nullable): The created object
  */
 GObject *
@@ -485,8 +470,7 @@ peas_object_module_create_object (PeasObjectModule *module,
                                   guint             n_parameters,
                                   GParameter       *parameters)
 {
-  PeasObjectModulePrivate *priv = GET_PRIV (module);
-  guint i;
+  PeasObjectModulePrivate *priv = peas_object_module_get_instance_private (module);
   ExtensionImplementation *impls;
 
   g_return_val_if_fail (PEAS_IS_OBJECT_MODULE (module), NULL);
@@ -494,7 +478,7 @@ peas_object_module_create_object (PeasObjectModule *module,
                         G_TYPE_IS_ABSTRACT (exten_type), NULL);
 
   impls = (ExtensionImplementation *) priv->implementations->data;
-  for (i = 0; i < priv->implementations->len; ++i)
+  for (guint i = 0; i < priv->implementations->len; i++)
     {
       if (impls[i].exten_type == exten_type)
         return impls[i].func (n_parameters, parameters, impls[i].user_data);
@@ -511,16 +495,13 @@ G_GNUC_END_IGNORE_DEPRECATIONS
  *
  * Determines if the module provides an extension for @exten_type.
  *
- * Since libpeas 1.22, @exten_type can be an Abstract [alias@GObject.Type]
- * and not just an Interface [alias@GObject.Type].
- *
  * Returns: if the module provides an extension for @exten_type.
  */
 gboolean
 peas_object_module_provides_object (PeasObjectModule *module,
                                     GType             exten_type)
 {
-  PeasObjectModulePrivate *priv = GET_PRIV (module);
+  PeasObjectModulePrivate *priv = peas_object_module_get_instance_private (module);
   guint i;
   ExtensionImplementation *impls;
 
@@ -546,10 +527,10 @@ peas_object_module_provides_object (PeasObjectModule *module,
  *
  * Returns: the path.
  */
-const gchar *
+const char *
 peas_object_module_get_path (PeasObjectModule *module)
 {
-  PeasObjectModulePrivate *priv = GET_PRIV (module);
+  PeasObjectModulePrivate *priv = peas_object_module_get_instance_private (module);
 
   g_return_val_if_fail (PEAS_IS_OBJECT_MODULE (module), NULL);
 
@@ -564,10 +545,10 @@ peas_object_module_get_path (PeasObjectModule *module)
  *
  * Returns: the module name.
  */
-const gchar *
+const char *
 peas_object_module_get_module_name (PeasObjectModule *module)
 {
-  PeasObjectModulePrivate *priv = GET_PRIV (module);
+  PeasObjectModulePrivate *priv = peas_object_module_get_instance_private (module);
 
   g_return_val_if_fail (PEAS_IS_OBJECT_MODULE (module), NULL);
 
@@ -584,10 +565,10 @@ peas_object_module_get_module_name (PeasObjectModule *module)
  *
  * Since: 1.18
  */
-const gchar *
+const char *
 peas_object_module_get_symbol (PeasObjectModule *module)
 {
-  PeasObjectModulePrivate *priv = GET_PRIV (module);
+  PeasObjectModulePrivate *priv = peas_object_module_get_instance_private (module);
 
   g_return_val_if_fail (PEAS_IS_OBJECT_MODULE (module), NULL);
 
@@ -605,7 +586,7 @@ peas_object_module_get_symbol (PeasObjectModule *module)
 GModule *
 peas_object_module_get_library (PeasObjectModule *module)
 {
-  PeasObjectModulePrivate *priv = GET_PRIV (module);
+  PeasObjectModulePrivate *priv = peas_object_module_get_instance_private (module);
 
   g_return_val_if_fail (PEAS_IS_OBJECT_MODULE (module), NULL);
 
@@ -629,9 +610,6 @@ peas_object_module_get_library (PeasObjectModule *module)
  * creating native types which cannot be instantiated correctly using
  * [ctor@GObject.Object.new].  For other uses, you will usually prefer relying on
  * peas_object_module_register_extension_type().
- *
- * Since libpeas 1.22, @exten_type can be an Abstract [alias@GObject.Type]
- * and not just an Interface [alias@GObject.Type].
  */
 void
 peas_object_module_register_extension_factory (PeasObjectModule *module,
@@ -640,7 +618,7 @@ peas_object_module_register_extension_factory (PeasObjectModule *module,
                                                gpointer          user_data,
                                                GDestroyNotify    destroy_func)
 {
-  PeasObjectModulePrivate *priv = GET_PRIV (module);
+  PeasObjectModulePrivate *priv = peas_object_module_get_instance_private (module);
   ExtensionImplementation impl = { exten_type, factory_func, user_data, destroy_func };
 
   g_return_if_fail (PEAS_IS_OBJECT_MODULE (module));
@@ -693,9 +671,6 @@ G_GNUC_END_IGNORE_DEPRECATIONS
  * @impl_type: The #GType of your implementation of @exten_type.
  *
  * Register @impl_type as an extension which implements @extension_type.
- *
- * Since libpeas 1.22, @exten_type can be an Abstract [alias@GObject.Type]
- * and not just an Interface [alias@GObject.Type].
  */
 void
 peas_object_module_register_extension_type (PeasObjectModule *module,
