@@ -17,12 +17,15 @@
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
+ *
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  */
 
-#ifndef __INTROSPECTION_BASE_H__
-#define __INTROSPECTION_BASE_H__
+#pragma once
 
-#include <libpeas/peas.h>
+#include <libpeas.h>
+
+#include "../../testing-util/peas-test-common.h"
 
 G_BEGIN_DECLS
 
@@ -49,11 +52,14 @@ struct _IntrospectionBaseInterface {
 /*
  * Public methods
  */
+PEAS_TEST_EXPORT
 GType      introspection_base_get_type     (void) G_GNUC_CONST;
 
+
+PEAS_TEST_EXPORT
 const PeasPluginInfo *introspection_base_get_plugin_info (IntrospectionBase *base);
+
+PEAS_TEST_EXPORT
 GSettings            *introspection_base_get_settings    (IntrospectionBase *base);
 
 G_END_DECLS
-
-#endif /* __INTROSPECTION_BASE_H__ */
