@@ -17,17 +17,19 @@
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
+ *
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  */
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
+#include "config.h"
 
 #include <glib.h>
 #include <glib-object.h>
 #include <gmodule.h>
 
-#include <libpeas/peas.h>
+#include <libpeas.h>
+
+#include "introspection-activatable.h"
 
 #include "has-dep-plugin.h"
 
@@ -35,15 +37,15 @@ typedef struct {
   GObject *object;
 } TestingHasDepPluginPrivate;
 
-static void peas_activatable_iface_init (PeasActivatableInterface *iface);
+static void introspection_activatable_iface_init (IntrospectionActivatableInterface *iface);
 
 G_DEFINE_DYNAMIC_TYPE_EXTENDED (TestingHasDepPlugin,
                                 testing_has_dep_plugin,
                                 PEAS_TYPE_EXTENSION_BASE,
                                 0,
                                 G_ADD_PRIVATE_DYNAMIC (TestingHasDepPlugin)
-                                G_IMPLEMENT_INTERFACE_DYNAMIC (PEAS_TYPE_ACTIVATABLE,
-                                                               peas_activatable_iface_init))
+                                G_IMPLEMENT_INTERFACE_DYNAMIC (INTROSPECTION_TYPE_ACTIVATABLE,
+                                                               introspection_activatable_iface_init))
 
 #define GET_PRIV(o) \
   (testing_has_dep_plugin_get_instance_private (o))
@@ -101,12 +103,12 @@ testing_has_dep_plugin_init (TestingHasDepPlugin *plugin)
 }
 
 static void
-testing_has_dep_plugin_activate (PeasActivatable *activatable)
+testing_has_dep_plugin_activate (IntrospectionActivatable *activatable)
 {
 }
 
 static void
-testing_has_dep_plugin_deactivate (PeasActivatable *activatable)
+testing_has_dep_plugin_deactivate (IntrospectionActivatable *activatable)
 {
 }
 
@@ -122,7 +124,7 @@ testing_has_dep_plugin_class_init (TestingHasDepPluginClass *klass)
 }
 
 static void
-peas_activatable_iface_init (PeasActivatableInterface *iface)
+introspection_activatable_iface_init (IntrospectionActivatableInterface *iface)
 {
   iface->activate = testing_has_dep_plugin_activate;
   iface->deactivate = testing_has_dep_plugin_deactivate;
@@ -139,6 +141,6 @@ peas_register_types (PeasObjectModule *module)
   testing_has_dep_plugin_register_type (G_TYPE_MODULE (module));
 
   peas_object_module_register_extension_type (module,
-                                              PEAS_TYPE_ACTIVATABLE,
+                                              INTROSPECTION_TYPE_ACTIVATABLE,
                                               TESTING_TYPE_HAS_DEP_PLUGIN);
 }
